@@ -84,7 +84,7 @@ class Archiver(object):
         archive_files = []
         for root, dirs, files in os.walk(data_dir):
             for file in files:
-                if not file.endswith('~') and not 'RedNotebook-Backup' in file:
+                if not file.endswith('~') and 'RedNotebook-Backup' not in file:
                     archive_files.append(os.path.join(root, file))
 
         write_archive(backup_file, archive_files, data_dir)
