@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------
-# Copyright (c) 2009, 2014  Jendrik Seipp
+# Copyright (c) 2009, 2014, 2015  Jendrik Seipp
 #
 # RedNotebook is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,39 +20,59 @@
 import os
 import logging
 
+from rednotebook.gui import editor
 from rednotebook.util import filesystem
 
 
-
 def delete_comment(line):
     if line.startswith('#'):
         return u''
     return line
 
 
-
 class Config(dict):
+    defaults = {
+        'mainFont': editor.DEFAULT_FONT,
+        # mingliu and MS Mincho are required for displaying Asian fonts
+        # in preview mode on Windows.
+        'previewFont': 'Ubuntu, mingliu, MS Mincho, sans-serif',
+        'closeToTray': 0,
+        'checkForNewVersion': 0,
+        'weekNumbers': 0,
+        'portable': 0,
+        'userDir': '',
+        'firstStart': 1,
+        'spellcheck': 0,
+        'mainFrameWidth': 1024,
+        'mainFrameHeight': 700,
+        'mainFrameMaximized': 0,
+        'mainFrameX': None,
+        'mainFrameY': None,
+        'leftDividerPosition': 250,
+        'rightDividerPosition': None,
+    }
+
+    obsolete_keys = set([
+        u'useGTKMozembed', u'useWebkit', u'LD_LIBRARY_PATH',
+        u'MOZILLA_FIVE_HOME', u'cloudTabActive', u'mainFontSize',
+        u'running'
+    ])
+
+    # Allow changing the value of portable only in default.cfg.
+    suppressed_keys = set(['portable', 'user_dir'])
+
     def __init__(self, config_file):
         dict.__init__(self)
 
         self.filename = config_file
 
-        self.obsolete_keys = [
-            u'useGTKMozembed', u'useWebkit', u'LD_LIBRARY_PATH',
-            u'MOZILLA_FIVE_HOME', u'cloudTabActive', u'mainFontSize',
-            u'running']
-
-        # Allow changing the value of portable only in default.cfg
-        self.suppressed_keys = ['portable', 'user_dir']
-
         self.update(self._read_file(self.filename))
-
+        self.save_state()
 
     def save_state(self):
         ''' Save a copy of the dir to check for changes later '''
         self.old_config = self.copy()
 
-
     def _read_file(self, filename):
         content = filesystem.read_file(filename)
 
@@ -79,13 +99,17 @@ class Config(dict):
 
         return dictionary
 
+    def read(self, key, default=None):
+        '''
+        Get the stored value for the given key.
 
-    def read(self, key, default):
-        if key in self:
-            return self[key]
-        self[key] = default
-        return default
-
+        If *default* is omitted, there must be a default for *key* in
+        Config.defaults. If *default* is given and there is no value
+        stored for *key*, set the stored value to *default*.
+        '''
+        if default is None:
+            default = self.defaults[key]
+        return self.setdefault(key, default)
 
     def read_list(self, key, default):
         '''
@@ -105,15 +129,12 @@ class Config(dict):
         strings = [s.strip() for s in string.split()]
         return [s for s in strings if s]
 
-
     def write_list(self, key, list):
         self[key] = ', '.join(list)
 
-
     def changed(self):
         return not (self == self.old_config)
 
-
     def save_to_disk(self):
         if not self.changed():
             return
