@@ -30,7 +30,7 @@ ALPHA_NUMERIC = r'\w'
 HEX = r'[0-9A-F]{6}'
 HASHTAG_EXCLUDES = r'%(HEX)s|include' % locals()
 HASHTAG_TEXT = r'%(ALPHA_NUMERIC)s*%(ALPHA)s+%(ALPHA_NUMERIC)s*' % locals()
-HASHTAG_PATTERN = r'(^|[^%(ALPHA_NUMERIC)s&]+)(#|\uFF03)(?!%(HASHTAG_EXCLUDES)s)(%(HASHTAG_TEXT)s)' % locals()
+HASHTAG_PATTERN = r'(^|[^%(ALPHA_NUMERIC)s&#]+)(#|\uFF03)(?!%(HASHTAG_EXCLUDES)s)(%(HASHTAG_TEXT)s)' % locals()
 HASHTAG = re.compile(HASHTAG_PATTERN, flags=re.I | re.U)
 
 def escape_tag(tag):
@@ -88,9 +88,7 @@ class Day(object):
             day_content = {'text': u''}
 
         self.date = datetime.date(month.year_number, month.month_number, day_number)
-
         self.month = month
-        self.day_number = day_number
 
         # Turn all entries of old "Tags" categories into tags without entries.
         old_tags = day_content.pop('Tags', {})
