@@ -49,11 +49,11 @@ class CustomComboBoxEntry(object):
         self.entry = self.combo_box.get_child()
 
         # Autocompletion
-        self.entry_completion = gtk.EntryCompletion()
-        self.entry_completion.set_model(self.liststore)
-        self.entry_completion.set_minimum_key_length(1)
-        self.entry_completion.set_text_column(0)
-        self.entry.set_completion(self.entry_completion)
+        entry_completion = gtk.EntryCompletion()
+        entry_completion.set_model(self.liststore)
+        entry_completion.set_minimum_key_length(1)
+        entry_completion.set_text_column(0)
+        self.entry.set_completion(entry_completion)
 
     def add_entry(self, entry):
         self.liststore.append([entry])
@@ -132,20 +132,21 @@ class Calendar(gtk.Calendar):
         self.select_day(1)
 
         # PyGTK calendars show months in range [0,11]
-        self.select_month(date.month-1, date.year)
+        self.select_month(date.month - 1, date.year)
 
         # Select the day after the month and year have been set
         self.select_day(date.day)
 
     def get_date(self):
         year, month, day = gtk.Calendar.get_date(self)
-        return datetime.date(year, month+1, day)
+        return datetime.date(year, month + 1, day)
 
 
 # gtk.InfoBar is available in gtk+ >= 2.22
 if hasattr(gtk, 'InfoBar'):
     class Info(gtk.InfoBar):
         icons = {gtk.MESSAGE_ERROR: gtk.STOCK_DIALOG_ERROR}
+
         def __init__(self, *args, **kwargs):
             gtk.InfoBar.__init__(self, *args, **kwargs)
             self.title_label = gtk.Label()
@@ -247,7 +248,7 @@ class RadioButtonPage(AssistantPage):
         if tooltip:
             description = gtk.Label()
             description.set_alignment(0.0, 0.5)
-            description.set_markup(' '*5 + tooltip)
+            description.set_markup(' ' * 5 + tooltip)
             description.set_sensitive(sensitive)
             self.pack_start(description, False, False)
 
@@ -365,3 +366,38 @@ class Assistant(gtk.Assistant):
         self.set_page_title(page, _('Introduction'))
         self.set_page_type(page, gtk.ASSISTANT_PAGE_INTRO)
         self.set_page_complete(page, True)
+
+
+class TemplateBar(gtk.HBox):
+    def __init__(self):
+        gtk.HBox.__init__(self)
+        self.set_spacing(2)
+        label = gtk.Label('<b>%s</b>:' % _('Template'))
+        label.set_use_markup(True)
+        self.pack_start(label, False, False)
+        self.save_insert_button = gtk.Button(_('Save and insert'))
+        self.pack_start(self.save_insert_button, False, False)
+        self.save_button = gtk.Button(stock=gtk.STOCK_SAVE)
+        self.pack_start(self.save_button, False, False)
+        self.close_button = gtk.Button(stock=gtk.STOCK_CLOSE)
+        self.pack_start(self.close_button, False, False)
+        self.show_all()
+
+
+class ToolbarMenuButton(gtk.MenuToolButton):
+    def __init__(self, stock_id, menu):
+        gtk.MenuToolButton.__init__(self, stock_id)
+        self.set_menu(menu)
+        self.connect('clicked', self.show_menu)
+        self.show()
+
+    def show_menu(self, button):
+        """
+        Show the menu when the button is clicked.
+
+        A little hack for button and activate_time is needed as the "clicked" does
+        not have an associated event parameter. Otherwise we would use event.button
+        and event.time
+        """
+        self.get_menu().popup(parent_menu_shell=None, parent_menu_item=None,
+                              func=None, button=0, activate_time=0, data=None)
