@@ -186,7 +186,7 @@ class Journal:
         self.title = ''
 
         # show instructions at first start
-        self.is_first_start = self.config.read('firstStart', 1)
+        self.is_first_start = self.config.read('firstStart')
         self.config['firstStart'] = 0
         logging.info('First Start: %s' % bool(self.is_first_start))
 
@@ -214,7 +214,7 @@ class Journal:
         #self.archiver.check_last_backup_date()
 
         # Check for a new version
-        if self.config.read('checkForNewVersion', 0) == 1:
+        if self.config.read('checkForNewVersion') == 1:
             utils.check_new_version(self, info.version, startup=True)
 
         # Automatically save the content after a period of time
@@ -285,7 +285,7 @@ class Journal:
 
     def convert(self, text, target, headers=None, options=None):
         options = options or {}
-        options['font'] = self.config.read('previewFont', 'Ubuntu, sans-serif')
+        options['font'] = self.config.read('previewFont')
         return markup.convert(text, target, self.dirs.data_dir, headers=headers, options=options)
 
     def save_to_disk(self, exit_imminent=False, changing_journal=False, saveas=False):
@@ -297,8 +297,12 @@ class Journal:
             self.frame.show_save_error_dialog(exit_imminent)
             return True
 
-        something_saved = storage.save_months_to_disk(self.months,
-            self.dirs.data_dir, self.frame, exit_imminent, saveas)
+        try:
+            something_saved = storage.save_months_to_disk(
+                self.months, self.dirs.data_dir, exit_imminent, saveas)
+        except (IOError, OSError):
+            self.frame.show_save_error_dialog(exit_imminent)
+            something_saved = None
 
         if something_saved:
             self.show_message(_('The content has been saved to %s') % self.dirs.data_dir, error=False)
@@ -407,7 +411,6 @@ class Journal:
 
         if not Month.same_month(new_date, old_date) or self.month is None:
             self.month = self.get_month(self.date)
-            #self.month.visited = True
 
         self.frame.set_date(self.month, self.date, self.day)
 
@@ -433,6 +436,11 @@ class Journal:
 
 
     def change_date(self, new_date):
+        if new_date < datetime.date(1900, 1, 1):
+            self.show_message('Only dates after 1900 are supported.',
+                              title='Too Early', error=True)
+            return
+
         if new_date == self.date:
             return
 
@@ -459,14 +467,16 @@ class Journal:
     def show_message(self, msg, title=None, error=False):
         if error and not title:
             title = _('Error')
+
         if error:
             msg_type = gtk.MESSAGE_ERROR
             log_level = logging.ERROR
         else:
             msg_type = gtk.MESSAGE_INFO
             log_level = logging.INFO
+
         self.frame.show_message(title, msg, msg_type)
-        logging.log(log_level, '%s. %s' % (title, msg))
+        logging.log(log_level, '%s. %s' % (title, msg) if title else msg)
 
 
     @property
@@ -476,7 +486,7 @@ class Journal:
 
 
     def normalize_tag(self, tag):
-        return tag.replace(' ', '').lower()
+        return tag.replace(' ', '_').lower()
 
 
     def get_entries(self, category):
